import { Connection, PublicKey, Transaction, TransactionInstruction, TransactionSignature } from "@solana/web3.js";
import BN from "bn.js";
import { ActionType } from "../core";
import { Obligation } from "../state/obligation";
import { MarketConfigType, ReserveConfigType, SupplyToEarnApy, SupplyToEarnReward } from "./shared";
export declare class RelendAction {
    programId: PublicKey;
    connection: Connection;
    reserve: ReserveConfigType;
    lendingMarket: MarketConfigType;
    publicKey: PublicKey;
    obligationAddress: PublicKey;
    obligationAccountInfo: Obligation | null;
    userTokenAccountAddress: PublicKey;
    userCollateralAccountAddress: PublicKey;
    seed: string;
    symbol: string;
    positions?: number;
    amount: BN;
    hostAta?: PublicKey;
    setupIxs: Array<TransactionInstruction>;
    lendingIxs: Array<TransactionInstruction>;
    cleanupIxs: Array<TransactionInstruction>;
    preTxnIxs: Array<TransactionInstruction>;
    postTxnIxs: Array<TransactionInstruction>;
    depositReserves: Array<PublicKey>;
    borrowReserves: Array<PublicKey>;
    supplyToEarnApys: Array<SupplyToEarnApy>;
    supplyToEarnRewards: Array<SupplyToEarnReward>;
    private constructor();
    static initialize(action: ActionType, amount: string | BN, symbol: string, publicKey: PublicKey, connection: Connection, environment?: "production" | "devnet" | "testnet", supplyToEarnApys?: SupplyToEarnApy[], supplyToEarnRewards?: SupplyToEarnReward[], lendingMarketAddress?: PublicKey, hostAddress?: PublicKey): Promise<RelendAction>;
    static buildDepositTxns(connection: Connection, amount: string | BN, symbol: string, publicKey: PublicKey, environment?: "production" | "devnet" | "testnet", supplyToEarnApys?: SupplyToEarnApy[], supplyToEarnRewards?: SupplyToEarnReward[], lendingMarketAddress?: PublicKey): Promise<RelendAction>;
    static buildBorrowTxns(connection: Connection, amount: string | BN, symbol: string, publicKey: PublicKey, environment?: "production" | "devnet" | "testnet", supplyToEarnApys?: SupplyToEarnApy[], supplyToEarnRewards?: SupplyToEarnReward[], hostAddress?: PublicKey, lendingMarketAddress?: PublicKey): Promise<RelendAction>;
    static buildDepositReserveLiquidityTxns(connection: Connection, amount: string | BN, symbol: string, publicKey: PublicKey, environment?: "production" | "devnet" | "testnet", supplyToEarnApys?: SupplyToEarnApy[], supplyToEarnRewards?: SupplyToEarnReward[], lendingMarketAddress?: PublicKey): Promise<RelendAction>;
    static buildRedeemReserveCollateralTxns(connection: Connection, amount: string | BN, symbol: string, publicKey: PublicKey, environment?: "production" | "devnet" | "testnet", supplyToEarnApys?: SupplyToEarnApy[], supplyToEarnRewards?: SupplyToEarnReward[], lendingMarketAddress?: PublicKey): Promise<RelendAction>;
    static buildDepositObligationCollateralTxns(connection: Connection, amount: string | BN, symbol: string, publicKey: PublicKey, environment?: "production" | "devnet" | "testnet", supplyToEarnApys?: SupplyToEarnApy[], supplyToEarnRewards?: SupplyToEarnReward[], lendingMarketAddress?: PublicKey): Promise<RelendAction>;
    static buildWithdrawTxns(connection: Connection, amount: string | BN, symbol: string, publicKey: PublicKey, environment?: "production" | "devnet" | "testnet", supplyToEarnApys?: SupplyToEarnApy[], supplyToEarnRewards?: SupplyToEarnReward[], lendingMarketAddress?: PublicKey): Promise<RelendAction>;
    static buildRepayTxns(connection: Connection, amount: string | BN, symbol: string, publicKey: PublicKey, environment?: "production" | "devnet" | "testnet", supplyToEarnApys?: SupplyToEarnApy[], supplyToEarnRewards?: SupplyToEarnReward[], lendingMarketAddress?: PublicKey): Promise<RelendAction>;
    getTransactions(): Promise<{
        preLendingTxn: Transaction | null;
        lendingTxn: Transaction | null;
        postLendingTxn: Transaction | null;
    }>;
    sendTransactions(sendTransaction: (txn: Transaction, connection: Connection) => Promise<TransactionSignature>, preCallback?: () => void, lendingCallback?: () => void, postCallback?: () => void): Promise<string>;
    private sendSingleTransaction;
    addDepositIx(): Promise<void>;
    addDepositReserveLiquidityIx(): void;
    addRedeemReserveCollateralIx(): void;
    addDepositObligationCollateralIx(): void;
    addBorrowIx(): void;
    addWithdrawIx(): Promise<void>;
    addRepayIx(): Promise<void>;
    addSupportIxs(action: ActionType): Promise<void>;
    private addRefreshIxs;
    private addObligationIxs;
    private addAtaIxs;
    private updateWRENECAccount;
    private formatReserveData;
    private calculateSupplyAPY;
    private calculateBorrowAPY;
    private calculateSupplyAPR;
    private calculateUtilizationRatio;
    private calculateBorrowAPR;
}
