import { OptionMarketWithKey } from "@mithraic-labs/psy-american";
import * as anchor from "@project-serum/anchor";
import { Wallet } from "@project-serum/anchor/dist/cjs/provider";
import { Connection, PublicKey } from "@solana/web3.js";
import { RelendClaim } from "./claim";
import { ConfigType } from "./shared";
export type ClaimType = {
    obligationID: string;
    lotNumber: number;
    index: number;
    quantity: string;
    root: string;
    proof: Array<string>;
    distributorPublicKey: string;
    name: string;
    incentivizer: string;
    optionMarketKey: string;
};
export type EnrichedClaimType = {
    claimable: boolean;
    claimedAt: number | null;
    mintAddress: string;
    quantity: string;
    distributor: {
        mint: PublicKey;
        bump: number;
    };
    distributorATAPublicKey: PublicKey;
    claimId: PublicKey;
    claimStatusBump: number;
    optionMarket: (OptionMarketWithKey & {
        userBalance: number;
    }) | null;
} & ClaimType;
export type RelendReward = {
    lifetimeAmount: number;
    symbol: string;
    claimedAmount: number;
    claimableAmount: number;
    rewardClaims: Array<RelendClaim>;
};
export declare class RelendWallet {
    config: ConfigType | null;
    rewards: {
        [key: string]: RelendReward;
    };
    provider: anchor.Provider;
    programId: PublicKey;
    private constructor();
    static initialize(wallet: Wallet, connection: Connection, environment?: "production" | "testnet"): Promise<RelendWallet>;
    loadRewards(): Promise<void>;
    getClaimAllIxs(): Promise<anchor.web3.TransactionInstruction[][]>;
}
