/// <reference types="node" />
import { Connection, PublicKey } from "@solana/web3.js";
import BigNumber from "bignumber.js";
import { Obligation } from "../../state";
import { PoolType } from "../types";
export declare function formatObligation(obligation: {
    pubkey: PublicKey;
    info: Obligation;
}, pool: PoolType): {
    address: string;
    positions: number;
    deposits: {
        liquidationThreshold: number;
        loanToValueRatio: number;
        symbol: string | undefined;
        price: BigNumber;
        reserveAddress: string;
        amount: BigNumber;
        amountUsd: BigNumber;
        depositedAmount: BigNumber;
        earnedAmount: BigNumber;
    }[];
    borrows: {
        liquidationThreshold: number;
        loanToValueRatio: number;
        symbol: string | undefined;
        price: BigNumber;
        cumulativeBorrowRate: BigNumber;
        reserveAddress: string;
        amount: BigNumber;
        amountUsd: BigNumber;
        weightedAmountUsd: BigNumber;
    }[];
    poolAddress: string;
    totalSupplyValue: BigNumber;
    totalBorrowValue: BigNumber;
    borrowLimit: BigNumber;
    liquidationThreshold: BigNumber;
    netAccountValue: BigNumber;
    liquidationThresholdFactor: BigNumber;
    borrowLimitFactor: BigNumber;
    borrowUtilization: BigNumber;
    weightedConservativeBorrowUtilization: BigNumber;
    weightedBorrowUtilization: BigNumber;
    isBorrowLimitReached: boolean;
    borrowOverSupply: BigNumber;
    weightedTotalBorrowValue: BigNumber;
    minPriceUserTotalSupply: BigNumber;
    minPriceBorrowLimit: BigNumber;
    maxPriceUserTotalWeightedBorrow: BigNumber;
};
export declare function fetchObligationByAddress(obligationAddress: string, connection: Connection, debug?: boolean): Promise<{
    pubkey: PublicKey;
    account: {
        executable: boolean;
        owner: PublicKey;
        lamports: number;
        data: Buffer;
        rentEpoch?: number | undefined;
    };
    info: Obligation;
} | null>;
export declare function fetchObligationsByAddress(obligationAddresses: Array<string>, connection: Connection, debug?: boolean): Promise<{
    info: Obligation;
    pubkey: PublicKey;
}[]>;
