/// <reference types="bn.js" />
import { Connection, PublicKey } from "@solana/web3.js";
import BigNumber from "bignumber.js";
import { Reserve } from "../../state";
import { PoolType, ReserveType } from "../types";
export declare function fetchPools(oldPools: Array<PoolType>, connection: Connection, programId: string, currentSlot: number, debug?: boolean): Promise<{
    [k: string]: {
        name: string | null;
        address: string;
        authorityAddress: string;
        reserves: ReserveType[];
        owner: string;
    };
}>;
export declare function formatReserve(reserve: {
    pubkey: PublicKey;
    info: Reserve;
}, price: {
    spotPrice: number;
    emaPrice: number;
} | undefined, currentSlot: number): {
    accumulatedProtocolFeesWad: import("bn.js");
    totalBorrowWad: import("bn.js");
    availableAmountWad: import("bn.js");
    mintTotalSupplyWad: import("bn.js");
    disabled: boolean;
    cumulativeBorrowRate: BigNumber;
    cTokenExchangeRate: BigNumber;
    cTokenExchangeRateMintSupplyOnTotalSupply: BigNumber;
    reserveUtilization: BigNumber;
    cTokenMint: string;
    feeReceiverAddress: string;
    reserveSupplyLimit: BigNumber;
    reserveBorrowLimit: BigNumber;
    borrowFee: BigNumber;
    flashLoanFee: BigNumber;
    protocolLiquidationFee: number;
    hostFee: number;
    interestRateSpread: number;
    reserveSupplyCap: BigNumber;
    reserveBorrowCap: BigNumber;
    targetBorrowApr: number;
    targetUtilization: number;
    maxUtilizationRate: number;
    minBorrowApr: number;
    maxBorrowApr: number;
    superMaxBorrowRate: number;
    supplyAPRInterest: BigNumber;
    borrowAPRInterest: BigNumber;
    supplyAPYInterest: BigNumber;
    borrowAPYInterest: BigNumber;
    totalSupply: BigNumber;
    totalBorrow: BigNumber;
    availableAmount: BigNumber;
    rateLimiter: {
        remainingOutflow: BigNumber | null;
        config: {
            windowDuration: BigNumber;
            maxOutflow: BigNumber;
        };
        windowStart: BigNumber;
        previousQuantity: BigNumber;
        currentQuantity: BigNumber;
    };
    totalSupplyUsd: BigNumber;
    totalBorrowUsd: BigNumber;
    availableAmountUsd: BigNumber;
    loanToValueRatio: number;
    liquidationThreshold: number;
    maxLiquidationThreshold: number;
    liquidationPenalty: number;
    maxLiquidationPenalty: number;
    liquidityAddress: string;
    cTokenLiquidityAddress: string;
    liquidityFeeReceiverAddress: string;
    address: string;
    mintAddress: string;
    decimals: number;
    symbol: undefined;
    price: BigNumber;
    poolAddress: string;
    pythOracle: string;
    switchboardOracle: string;
    addedBorrowWeightBPS: import("bn.js");
    borrowWeight: number;
    lastUpdateSlot: import("bn.js");
    emaPrice: number | undefined;
    minPrice: BigNumber;
    maxPrice: BigNumber;
};
export declare const getReservesOfPool: (lendingMarketPubkey: PublicKey, connection: Connection, programId: string, currentSlot: number, debug?: boolean) => Promise<{
    accumulatedProtocolFeesWad: import("bn.js");
    totalBorrowWad: import("bn.js");
    availableAmountWad: import("bn.js");
    mintTotalSupplyWad: import("bn.js");
    disabled: boolean;
    cumulativeBorrowRate: BigNumber;
    cTokenExchangeRate: BigNumber;
    cTokenExchangeRateMintSupplyOnTotalSupply: BigNumber;
    reserveUtilization: BigNumber;
    cTokenMint: string;
    feeReceiverAddress: string;
    reserveSupplyLimit: BigNumber;
    reserveBorrowLimit: BigNumber;
    borrowFee: BigNumber;
    flashLoanFee: BigNumber;
    protocolLiquidationFee: number;
    hostFee: number;
    interestRateSpread: number;
    reserveSupplyCap: BigNumber;
    reserveBorrowCap: BigNumber;
    targetBorrowApr: number;
    targetUtilization: number;
    maxUtilizationRate: number;
    minBorrowApr: number;
    maxBorrowApr: number;
    superMaxBorrowRate: number;
    supplyAPRInterest: BigNumber;
    borrowAPRInterest: BigNumber;
    supplyAPYInterest: BigNumber;
    borrowAPYInterest: BigNumber;
    totalSupply: BigNumber;
    totalBorrow: BigNumber;
    availableAmount: BigNumber;
    rateLimiter: {
        remainingOutflow: BigNumber | null;
        config: {
            windowDuration: BigNumber;
            maxOutflow: BigNumber;
        };
        windowStart: BigNumber;
        previousQuantity: BigNumber;
        currentQuantity: BigNumber;
    };
    totalSupplyUsd: BigNumber;
    totalBorrowUsd: BigNumber;
    availableAmountUsd: BigNumber;
    loanToValueRatio: number;
    liquidationThreshold: number;
    maxLiquidationThreshold: number;
    liquidationPenalty: number;
    maxLiquidationPenalty: number;
    liquidityAddress: string;
    cTokenLiquidityAddress: string;
    liquidityFeeReceiverAddress: string;
    address: string;
    mintAddress: string;
    decimals: number;
    symbol: undefined;
    price: BigNumber;
    poolAddress: string;
    pythOracle: string;
    switchboardOracle: string;
    addedBorrowWeightBPS: import("bn.js");
    borrowWeight: number;
    lastUpdateSlot: import("bn.js");
    emaPrice: number | undefined;
    minPrice: BigNumber;
    maxPrice: BigNumber;
}[]>;
export declare const getReservesFromChain: (connection: Connection, programId: string, currentSlot: number, debug?: boolean) => Promise<{
    accumulatedProtocolFeesWad: import("bn.js");
    totalBorrowWad: import("bn.js");
    availableAmountWad: import("bn.js");
    mintTotalSupplyWad: import("bn.js");
    disabled: boolean;
    cumulativeBorrowRate: BigNumber;
    cTokenExchangeRate: BigNumber;
    cTokenExchangeRateMintSupplyOnTotalSupply: BigNumber;
    reserveUtilization: BigNumber;
    cTokenMint: string;
    feeReceiverAddress: string;
    reserveSupplyLimit: BigNumber;
    reserveBorrowLimit: BigNumber;
    borrowFee: BigNumber;
    flashLoanFee: BigNumber;
    protocolLiquidationFee: number;
    hostFee: number;
    interestRateSpread: number;
    reserveSupplyCap: BigNumber;
    reserveBorrowCap: BigNumber;
    targetBorrowApr: number;
    targetUtilization: number;
    maxUtilizationRate: number;
    minBorrowApr: number;
    maxBorrowApr: number;
    superMaxBorrowRate: number;
    supplyAPRInterest: BigNumber;
    borrowAPRInterest: BigNumber;
    supplyAPYInterest: BigNumber;
    borrowAPYInterest: BigNumber;
    totalSupply: BigNumber;
    totalBorrow: BigNumber;
    availableAmount: BigNumber;
    rateLimiter: {
        remainingOutflow: BigNumber | null;
        config: {
            windowDuration: BigNumber;
            maxOutflow: BigNumber;
        };
        windowStart: BigNumber;
        previousQuantity: BigNumber;
        currentQuantity: BigNumber;
    };
    totalSupplyUsd: BigNumber;
    totalBorrowUsd: BigNumber;
    availableAmountUsd: BigNumber;
    loanToValueRatio: number;
    liquidationThreshold: number;
    maxLiquidationThreshold: number;
    liquidationPenalty: number;
    maxLiquidationPenalty: number;
    liquidityAddress: string;
    cTokenLiquidityAddress: string;
    liquidityFeeReceiverAddress: string;
    address: string;
    mintAddress: string;
    decimals: number;
    symbol: undefined;
    price: BigNumber;
    poolAddress: string;
    pythOracle: string;
    switchboardOracle: string;
    addedBorrowWeightBPS: import("bn.js");
    borrowWeight: number;
    lastUpdateSlot: import("bn.js");
    emaPrice: number | undefined;
    minPrice: BigNumber;
    maxPrice: BigNumber;
}[]>;
