"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("../../core/index.js");
const web3_js_1 = require("@solana/web3.js");
const _1 = require("./index.js");
describe("Custom Oracle Functions", () => {
    let pdaMainnet;
    let pdaTestnet;
    let connectionMainnet;
    const PAIR_RE_BTC_MAINNET = core_1.PRICE_PAIRS_MAINNET.find((p) => p.baseSymbol === core_1.RE_BTC) || core_1.PRICE_PAIRS_TESTNET[1];
    const PRICE_ACCOUNT_MAINNET = "F7jKoXmoBGrTvEPj2PaD4XQc835ZQAu2eXWSNAGCzJUu";
    const PRODUCT_ACCOUNT_MAINNET = "5Vqgme5Zg8wS9gLd5gzAuqo5JdxC5ynM57XhqcBVzx2H";
    let invalidPublicKey;
    let invalidToken;
    beforeAll(() => {
        pdaMainnet = core_1.PDA_ORACLE_MAINNET;
        pdaTestnet = core_1.PDA_ORACLE_TESTNET;
        connectionMainnet = new web3_js_1.Connection(core_1.MAINNET_URL);
        invalidPublicKey = new web3_js_1.PublicKey("D6AEmUvndjyGkk8hFZRgxSu1MCBV5Hp5Sp4WrmYG2gqL");
        invalidToken = new web3_js_1.PublicKey("Bi7zp2gfb53vF5DsD7x43juznx6NA3H4kmTStA3E1MrW");
    });
    it("should return output of parsePriceOracle", async () => {
        const oracleProduct = pdaMainnet.product(new web3_js_1.PublicKey(PAIR_RE_BTC_MAINNET.quoteToken), new web3_js_1.PublicKey(PAIR_RE_BTC_MAINNET.baseToken));
        const oraclePrice = pdaMainnet.price(oracleProduct.key);
        const priceResult = await (0, _1.parsePriceOracle)(connectionMainnet, oraclePrice.key);
        expect(priceResult).toBeTruthy();
        expect(priceResult?.productAccount.toBase58()).toBe(PRODUCT_ACCOUNT_MAINNET);
    });
    it("should return null of parsePriceOracle when using wrong pda (testnet)", async () => {
        const oracleProduct = pdaTestnet.product(new web3_js_1.PublicKey(PAIR_RE_BTC_MAINNET.quoteToken), new web3_js_1.PublicKey(PAIR_RE_BTC_MAINNET.baseToken));
        const oraclePrice = pdaMainnet.price(oracleProduct.key);
        const priceResult = await (0, _1.parsePriceOracle)(connectionMainnet, oraclePrice.key);
        expect(priceResult).toBeNull();
    });
    it("should return output of parseProductOracle", async () => {
        const oracleProduct = pdaMainnet.product(new web3_js_1.PublicKey(PAIR_RE_BTC_MAINNET.quoteToken), new web3_js_1.PublicKey(PAIR_RE_BTC_MAINNET.baseToken));
        const productResult = await (0, _1.parseProductOracle)(connectionMainnet, oracleProduct.key);
        expect(productResult).toBeTruthy();
        expect(productResult?.quoteCurrency).toBe(core_1.RE_USD);
        expect(productResult?.baseCurrency).toBe(core_1.RE_BTC);
        expect(productResult?.quoteMint.toBase58()).toBe(PAIR_RE_BTC_MAINNET.quoteToken);
        expect(productResult?.baseMint.toBase58()).toBe(PAIR_RE_BTC_MAINNET.baseToken);
        expect(productResult?.priceAccount.toBase58()).toBe(PRICE_ACCOUNT_MAINNET);
    });
    it("should return null of parseProductOracle when using wrong pda (testnet)", async () => {
        const oracleProduct = pdaTestnet.product(new web3_js_1.PublicKey(PAIR_RE_BTC_MAINNET.quoteToken), new web3_js_1.PublicKey(PAIR_RE_BTC_MAINNET.baseToken));
        const productResult = await (0, _1.parseProductOracle)(connectionMainnet, oracleProduct.key);
        expect(productResult).toBeNull();
    });
    it("should handle failure in parsePriceOracle due to invalid public key", async () => {
        await expect((0, _1.parsePriceOracle)(connectionMainnet, invalidPublicKey)).resolves.toBeNull();
    });
    it("should handle failure in parseProductOracle due to invalid public key", async () => {
        await expect((0, _1.parseProductOracle)(connectionMainnet, invalidPublicKey)).resolves.toBeNull();
    });
    it("should handle failure in parsePriceOracle due to corrupted data", async () => {
        await expect((0, _1.parsePriceOracle)(connectionMainnet, invalidToken)).resolves.toBeNull();
    });
    it("should handle failure in parsePriceOracle due to corrupted data", async () => {
        await expect((0, _1.parseProductOracle)(connectionMainnet, invalidToken)).resolves.toBeNull();
    });
});
