"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const web3_js_1 = require("@solana/web3.js");
const axios_1 = __importDefault(require("axios"));
const eventemitter3_1 = require("eventemitter3");
const types_1 = require("./types.js");
const utils_1 = require("./utils.js");
class Client extends eventemitter3_1.EventEmitter {
    async fetchMints(cdnUrl, mints) {
        const tokenlist = await this.getFromTokenList(cdnUrl, mints);
        this.emit("tokens", { tokens: tokenlist, source: types_1.UTLSource.API });
        const fetchedPubkeys = (0, utils_1.publicKeysToMap)(tokenlist.map((token) => new web3_js_1.PublicKey(token.address)));
        // Here we don't use metaplex
        /* const mintsNotFetched = mints.filter(
          (mint) => !fetchedPubkeys[mint.toString()]
        );
    
        const metaplex = await this.getFromMetaplex(
          mintsNotFetched,
          (metaplexPartial) => {
            this.emit("tokens", {
              tokens: [...tokenlist, ...metaplexPartial],
              source: UTLSource.CHAIN,
            });
          }
        );
    
        const data = [...tokenlist, ...metaplex]; */
        const data = [...tokenlist];
        this.emit("tokens", { tokens: data, source: types_1.UTLSource.METADATA });
        return data;
    }
    async getFromTokenList(cdnUrl, mints) {
        return await this.fetchTokensCdn(cdnUrl, mints);
    }
    async downloadTokenlist(cdnUrl) {
        try {
            const { data } = await axios_1.default.get(cdnUrl);
            return data;
        }
        catch {
            return null;
        }
    }
    async fetchTokensCdn(cdnUrl, mints) {
        const tokenlist = await this.downloadTokenlist(cdnUrl);
        const mintsMap = (0, utils_1.publicKeysToMap)(mints);
        return tokenlist?.tokens.filter((token) => mintsMap[token.address]) ?? [];
    }
}
exports.default = Client;
